@@ -33,7 +33,7 @@ typedef  int UserBookmarkList[3];
 class LatexEditor : public QPlainTextEdit  {
    Q_OBJECT
 public:
-LatexEditor(QWidget *parent,QFont & efont, QColor colMath, QColor colCommand, QColor colKeyword,bool inlinespelling=false, QString ignoredWords="",Hunspell *spellChecker=0);
+LatexEditor(QWidget *parent,QFont & efont, QColor colMath, QColor colCommand, QColor colKeyword,bool inlinespelling=false, QString ignoredWords="",Hunspell *spellChecker=0,bool tabspaces=false,int tabwidth=4);
 ~LatexEditor();
 static void clearMarkerFormat(const QTextBlock &block, int markerId);
 void gotoLine( int line );
@@ -77,12 +77,15 @@ QList<QTextCursor> structcursor;
 
 void removeStructureItem(int offset,int len, int line);
 void appendStructureItem(int line,QString item,int type,const QTextCursor& cursor);
+void setOldStructureItem();
+void setStructureDirty();
 
 int getLastNumLines();
 void setLastNumLines(int n);
 
 QDateTime getLastSavedTime();
 void setLastSavedTime(QDateTime t);
+void setTabSettings(bool tabspaces,int tabwidth);
 
 class StructItem {
 public:
@@ -91,10 +94,19 @@ QString item;
 int type;
 QTextCursor cursor;
 StructItem(int l, const QString& it, int t,const QTextCursor& curs): line(l),item(it),type(t),cursor(curs) { };
+bool operator==( const StructItem other ) const
+    {
+    return ((item==other.item) && (type==other.type));
+    }
+bool operator<( const StructItem other ) const
+    {
+    return (item<other.item);
+    }
 };
 const QList<StructItem> getStructItems() const { return StructItemsList; }
 
 QString beginningLine();
+bool StructureHasChanged();
 public slots:
 void matchAll();
 void setHightLightLine();
@@ -102,8 +114,10 @@ void clearHightLightLine();
 
 
 private:
+bool tabSpaces;
+int tabWidth;
 QDateTime lastSavedTime;
-QList<StructItem> StructItemsList;
+QList<StructItem> StructItemsList, OldStructItemsList;
 QString encoding;
 int lastnumlines;
 //QString textUnderCursor() const;
@@ -134,7 +148,7 @@ void checkSpellingDocument();
 void insertCompletion(const QString &completion);
 void jumpToPdf();
 void jumpToEndBlock();
-
+void requestNewNumLines(int n);
 
 void matchPar();
 void matchLat();
@@ -154,6 +168,8 @@ void setBlockRange(int,int);
 void updatelineWidget();
 void requestUpdateStructure();
 void requestGotoStructure(int);
+void poshaschanged(int,int);
+void numLinesChanged(int);
 };
 
 #endif
